@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Laajenna</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Foorumin käyttäjät tasolla 2 ja sitä korkeammalla voivat liittyä beta-testiin viimeisillä päivityksillä.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>Tiivistetty</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>Numerot väliltä 1-99999 ovat sallittuja</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
