@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Développer</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Les utilisateurs du forum de niveau 2 et supérieur peuvent participer au test bêta pour recevoir les dernières mises à jour.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>Réduire</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>Seuls les nombres compris entre 1-99999 sont autorisés.</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
