@@ -337,7 +337,7 @@
     </message>
     <message>
         <source>Updates Notification</source>
-        <translation>Notificação de Atualizações</translation>
+        <translation>Notificar quando houver atualizações disponíveis</translation>
     </message>
     <message>
         <source>Clear Package Cache</source>
@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Expandir</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Os usuários com nível 2 ou superior no fórum podem participar do programa beta para testar as últimas atualizações.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>Recolher</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>Somente números entre 1-99999 são permitidos</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
@@ -462,7 +462,7 @@
     </message>
     <message>
         <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
-        <translation>Configurar as atualizações de segurança, download automático de atualizações e notificação de atualizações</translation>
+        <translation>Configure as configurações de atualização, atualizações de segurança, download automático de atualizações e notificações de atualização</translation>
     </message>
     <message>
         <source>Reboot now</source>
