@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Zgjeroje</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Përdorues forumi të nivelit 2 e më sipër mund të bëhen pjesë e testimeve beta, që të marrin përditësimet më të reja.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>Palose</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>Lejohen vetëm numra mes 1-99999</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
