@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Розгорнути</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Користувачі форуму рівня 2 та вищих рівнів можуть долучатися до тестування для отримання найсвіжіших оновлень.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>Згорнути</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>Можна використовувати лише числа у діапазоні 1-99999</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
