@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>展开</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>论坛2级及以上用户可加入内测，获取最新更新</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>收起</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>只允许输入1-99999</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation>加入deepin内测通道，以获取deepin最新更新内容</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
