@@ -3,7 +3,7 @@
     <name>CheckUpdate</name>
     <message>
         <source>Last check: </source>
-        <translation type="unfinished"/>
+        <translation>上次檢查更新時間：</translation>
     </message>
 </context>
 <context>
@@ -154,12 +154,12 @@
     </message>
     <message>
         <source>, </source>
-        <translation type="unfinished"/>
+        <translation>，</translation>
         <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
     </message>
     <message>
         <source>for more details, please visit </source>
-        <translation type="unfinished"/>
+        <translation>更多詳情請訪問</translation>
         <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
     </message>
 </context>
@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>展開</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>論壇2級及以上用户可加入內測，獲取最新更新</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>收起</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>只允許輸入1-99999</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation>加入deepin內測通道，以獲取deepin最新更新內容</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
@@ -446,7 +446,7 @@
     </message>
     <message>
         <source>Update size: </source>
-        <translation type="unfinished"/>
+        <translation>更新大小：</translation>
     </message>
     <message>
         <source>Update download failed</source>
